---------------------------------------------------------------------
--== Import ===--
---------------------------------------------------------------------

import "Turbine.Gameplay"
import "Turbine.UI"
import "Turbine.UI.Lotro"
import "Souru.SkillTimer.Shortcut"
import "Souru.SkillTimer.Type"
import "Souru.SkillTimer.Class"
import "Souru.SkillTimer.UI"


---------------------------------------------------------------------
--==  ===--
---------------------------------------------------------------------

SaveFile = nil
Windows = {}
OptionsWindow = nil

me = Turbine.Gameplay.LocalPlayer.GetInstance()
class = me:GetClass()

skillList = me:GetTrainedSkills()

---------------------------------------------------------------------
--== Basic Functions ===--
---------------------------------------------------------------------

function Save()

	Turbine.PluginData.Save(Turbine.DataScope.Character, "SkillSaveFile", SaveFile)

end

function mysplit (inputstr, sep)
        if sep == nil then
                sep = "%s"
        end
        local t={}
        for str in string.gmatch(inputstr, "([^"..sep.."]+)") do
                table.insert(t, str)
        end
        return t
end

function FindSkill(name)

	for i=1 , skillList:GetCount() , 1 do

		if name == skillList:GetItem(i):GetSkillInfo():GetName() then
		
			return skillList:GetItem(i)
		
		end
	
	end
		
	return nil

end

---------------------------------------------------------------------
--== Window Functions ===--
---------------------------------------------------------------------

function MoveWindows(bool)

	for i,window in ipairs(Windows) do
		window:Move(bool)
	end
	
	anchor.label:SetVisible(bool)
	anchor:SetMouseVisible(bool)
	
	if bool then
		anchor:SetBackColor(Turbine.UI.Color.Red)
	else
		anchor:SetBackColor()
	end

end


function RemoveWindow(index)

	for i=index, table.getn(SaveFile)-1, 1 do
	
		SaveFile[i] = SaveFile[i+1]
	
	end
	
	SaveFile[table.getn(SaveFile)] = nil
	Save()
	CreateWindows()

end

function AddNewWindow()

	local index = table.getn(SaveFile)+1
	
	SaveFile[index] = {}
	SaveFile[index]["name"] = "Window"..index
	SaveFile[index]["visible"] = true
	SaveFile[index]["orientation"] = true
	SaveFile[index]["distance"] = 30
	SaveFile[index]["opacity"] = 1
	SaveFile[index]["left"] = 500
	SaveFile[index]["top"] = 500
	SaveFile[index]["size"] = 32 
	
	AddNewSkillTo(index)

	return index

end

function ClearWindows()
	
	for i,window in ipairs(Windows) do
		Windows[i]:Remove()
		Windows[i] = nil
	end
	
end

function CreateWindows()

	if table.getn(Windows) > 0 then
		ClearWindows()
	end

	for i,data in ipairs(SaveFile) do
		Windows[i] = UI.Window(data)
	end

end


---------------------------------------------------------------------
--== Skill/Icon Functions ===--
---------------------------------------------------------------------

function RemoveItem(window, index)

	for i=index, table.getn(SaveFile[window])-1, 1 do
	
		SaveFile[window][i] = SaveFile[window][i+1]
	
	end
	
	SaveFile[window][table.getn(SaveFile[window])] = nil
	Save()
	CreateWindows()

end

function AddNewSkillTo(window)

	local index = table.getn(SaveFile[window])+1
	
	SaveFile[window][index] = {}
	SaveFile[window][index]["name"] = "New Item"
	SaveFile[window][index]["data"] = nil
	
	if index > 1 then
	
		SaveFile[window][index]["showoffcd"] = SaveFile[window][index-1]["showoffcd"]
		SaveFile[window][index]["showoncd"] = SaveFile[window][index-1]["showoncd"]
		SaveFile[window][index]["popupanchor"] = SaveFile[window][index-1]["popupanchor"]
		SaveFile[window][index]["cdopacity"] = SaveFile[window][index-1]["cdopacity"]
		SaveFile[window][index]["showpopup"] = SaveFile[window][index-1]["showpopup"]
		SaveFile[window][index]["popupsize"] = SaveFile[window][index-1]["popupsize"]		
		SaveFile[window][index]["resetTimer"] = SaveFile[window][index-1]["resetTimer"]
	
	else
	
		SaveFile[window][index]["showoffcd"] = true
		SaveFile[window][index]["showoncd"] = true
		SaveFile[window][index]["popupanchor"] = true
		SaveFile[window][index]["cdopacity"] = 0.4
		SaveFile[window][index]["showpopup"] = true
		SaveFile[window][index]["popupsize"] = 200		
		SaveFile[window][index]["resetTimer"] = 0
	
	end

	return index

end


---------------------------------------------------------------------
--== Pop-Up Anchor  ===--
---------------------------------------------------------------------

anchor = Turbine.UI.Window()
anchor:SetPosition(700,500)
anchor:SetSize(100,100)
anchor:SetMouseVisible(false)
anchor:SetVisible(true)

anchor.label = Turbine.UI.Label()
anchor.label:SetParent(anchor)
anchor.label:SetSize(anchor:GetSize())
anchor.label:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter)
anchor.label:SetText("Pop-Up Anchor")
anchor.label:SetVisible(false)
anchor.label:SetMouseVisible(false)

anchor.MouseDown = function( sender, args )
	if args.Button == Turbine.UI.MouseButton.Left then
		anchor.dragging = true	
		anchor.dragStartX = args.X
		anchor.dragStartY = args.Y
	end

end

anchor.MouseMove = function( sender, args )
	if anchor.dragging then
		local x,y = anchor:GetPosition()	
		x = x + ( args.X - anchor.dragStartX )
		y = y + ( args.Y - anchor.dragStartY )	
		anchor:SetPosition( x, y )	
	end
end

anchor.MouseUp = function( sender, args )
	if args.Button == Turbine.UI.MouseButton.Left then
		anchor.dragging = false
		SaveFile["anchorleft"],SaveFile["anchortop"] = anchor:GetPosition()
		Save()
	end
end

---------------------------------------------------------------------
--== LoadIn  ===--
---------------------------------------------------------------------


if Turbine.PluginData.Load(Turbine.DataScope.Character, "SkillSaveFile") ~= nil then

	SaveFile = Turbine.PluginData.Load(Turbine.DataScope.Character, "SkillSaveFile")
	anchor:SetPosition(SaveFile["anchorleft"], SaveFile["anchortop"])
	CreateWindows()

else

	SaveFile = {}
	SaveFile["anchorleft"] = 700
	SaveFile["anchortop"] = 500
		
end



---------------------------------------------------------------------
--== Chat-Comands  ===--
---------------------------------------------------------------------

command = Turbine.ShellCommand()

function command:Execute( _, str )
    if str == nil or string.len( str ) == 0 then
        return
    end

    local list  = { }
    local index = 1

    for word in str:gmatch( "%w+" ) do
        list[ index ] = word
        index = index + 1
    end

    local cmd = string.lower( list[ 1 ] )

    if cmd == "options" then
       
	   if OptionsWindow == UI.OptionsWindow() then
			
			OptionsWindow = UI.OptionsWindow()

	   end
	   
    elseif cmd == "reload" then
      
	  CreateWindows()
	  
    elseif table.getn(list) == 2 then

		if list[1] == "unload" then
		
			for i,window in ipairs(SaveFile) do
				if string.lower(window["name"]) == string.lower(list[2]) then
					window["visible"] = false
					Turbine.Shell.WriteLine("Window: ''"..list[2].."'' turned off.")
					 CreateWindows()
					 return
				end
			end
			
			Turbine.Shell.WriteLine( "Invalid Window Name: " .. string.lower(list[1]) )
		
		elseif list[1] == "load" then
		
			for i,window in ipairs(SaveFile) do
				if string.lower(window["name"]) == string.lower(list[2]) then
					window["visible"] = true
					Turbine.Shell.WriteLine("Window: ''"..list[2].."'' turned on.")
					 CreateWindows()
					 return
				end
			end
			
			Turbine.Shell.WriteLine( "Invalid Window Name: " .. list[1] )

		else
		
			Turbine.Shell.WriteLine( "Invalid command: " .. cmd )
		
		end
		
	else
        Turbine.Shell.WriteLine( "Invalid command: " .. cmd )
    end
end

Turbine.Shell.AddCommand( "st", command )

Turbine.Shell.WriteLine("SkillTimer: usage: /st [options][reload][load <windowname>][unload <windowname>]")
